@@ -1,5 +1,5 @@
 /* GSequencer - Advanced GTK Sequencer
- * Copyright (C) 2005-2019 Joël Krähemann
+ * Copyright (C) 2005-2021 Joël Krähemann
  *
  * This file is part of GSequencer.
  *
@@ -19,6 +19,7 @@
 
 #include <ags/X/editor/ags_select_acceleration_dialog_callbacks.h>
 
+#include <ags/X/ags_ui_provider.h>
 #include <ags/X/ags_window.h>
 #include <ags/X/ags_automation_window.h>
 #include <ags/X/ags_automation_editor.h>
@@ -57,28 +58,58 @@ ags_select_acceleration_dialog_add_callback(GtkWidget *button,
 					    AgsSelectAccelerationDialog *select_acceleration_dialog)
 {
   AgsWindow *window;
-  AgsAutomationEditor *automation_editor;
   AgsMachine *machine;
 
   GtkHBox *hbox;
   GtkComboBoxText *combo_box;
+  GtkCellRenderer *scope_cell_renderer_text;
+  GtkCellRenderer *port_cell_renderer_text;
   GtkButton *remove;
 
   AgsAudio *audio;
   AgsChannel *start_channel;
   AgsChannel *channel, *next_channel;
+
+  AgsApplicationContext *application_context;
+
+  GtkListStore *list_store;
+
+  GtkTreeIter iter;
   
   GList *start_port, *port;
 
-  gchar **collected_specifier;
+  gchar **collected_audio_specifier, **collected_input_specifier, **collected_output_specifier;
 
+  gboolean use_composite_editor;
   guint length;
 
-  window = AGS_WINDOW(select_acceleration_dialog->main_window);
-  automation_editor = window->automation_window->automation_editor;
+  /* application context */
+  application_context = ags_application_context_get_instance();
 
-  machine = automation_editor->selected_machine;
+  use_composite_editor = ags_ui_provider_use_composite_editor(AGS_UI_PROVIDER(application_context));
 
+  window = ags_ui_provider_get_window(AGS_UI_PROVIDER(application_context));
+
+  machine = NULL;
+
+  if(use_composite_editor){
+    AgsCompositeEditor *composite_editor;
+    
+    composite_editor = window->composite_editor;
+
+    machine = composite_editor->selected_machine;
+  }else{
+    AgsAutomationEditor *automation_editor;
+    
+    automation_editor = window->automation_window->automation_editor;
+
+    machine = automation_editor->selected_machine;
+  }
+  
+  if(machine == NULL){
+    return;
+  }
+  
   audio = machine->audio;
 
   /* select automation */
@@ -90,16 +121,40 @@ ags_select_acceleration_dialog_add_callback(GtkWidget *button,
 		     0);
 
   /* automation combo box */
-  combo_box = (GtkComboBoxText *) gtk_combo_box_text_new();
+  combo_box = (GtkComboBox *) gtk_combo_box_new();
+
+  list_store = gtk_list_store_new(2,
+				  G_TYPE_STRING,
+				  G_TYPE_STRING);
+  
+  gtk_combo_box_set_model(combo_box,
+			  GTK_TREE_MODEL(list_store));
+
+  scope_cell_renderer_text = gtk_cell_renderer_text_new();
+  gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(combo_box),
+			     scope_cell_renderer_text,
+			     FALSE);
+  gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT(combo_box), scope_cell_renderer_text,
+				 "text", 0,
+				 NULL);
+
+  port_cell_renderer_text = gtk_cell_renderer_text_new();
+  gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(combo_box),
+			     port_cell_renderer_text,
+			     FALSE);
+  gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT(combo_box), port_cell_renderer_text,
+				 "text", 1,
+				 NULL);
+  
   gtk_box_pack_start((GtkBox *) hbox,
 		     GTK_WIDGET(combo_box),
 		     FALSE, FALSE,
 		     0);
 
   /*  */  
-  collected_specifier = (gchar **) malloc(sizeof(gchar*));
+  collected_audio_specifier = (gchar **) malloc(sizeof(gchar*));
 
-  collected_specifier[0] = NULL;
+  collected_audio_specifier[0] = NULL;
   length = 1;
   
   /* audio */
@@ -113,6 +168,10 @@ ags_select_acceleration_dialog_add_callback(GtkWidget *button,
 
     gboolean is_enabled;
     gboolean contains_control_name;
+
+    plugin_port = NULL;
+    
+    specifier = NULL;
     
     g_object_get(port->data,
 		 "specifier", &specifier,
@@ -120,26 +179,35 @@ ags_select_acceleration_dialog_add_callback(GtkWidget *button,
 		 NULL);
 
 #ifdef HAVE_GLIB_2_44
-    contains_control_name = g_strv_contains(collected_specifier,
+    contains_control_name = g_strv_contains(collected_audio_specifier,
 					    specifier);
 #else
-    contains_control_name = ags_strv_contains(collected_specifier,
+    contains_control_name = ags_strv_contains(collected_audio_specifier,
 					      specifier);
 #endif
 
     if(plugin_port != NULL &&
        !contains_control_name){
-      gtk_combo_box_text_append_text(combo_box,
-				     g_strdup(specifier));
+      gtk_list_store_append(list_store, &iter);
+      gtk_list_store_set(list_store, &iter,
+			 0, g_strdup("audio"),
+			 1, g_strdup(specifier),
+			 -1);      
 
       /* add to collected specifier */
-      collected_specifier = (gchar **) realloc(collected_specifier,
-				     (length + 1) * sizeof(gchar *));
-      collected_specifier[length - 1] = g_strdup(specifier);
-      collected_specifier[length] = NULL;
+      collected_audio_specifier = (gchar **) realloc(collected_audio_specifier,
+						     (length + 1) * sizeof(gchar *));
+      collected_audio_specifier[length - 1] = g_strdup(specifier);
+      collected_audio_specifier[length] = NULL;
 
       length++;
     }
+
+    if(plugin_port != NULL){
+      g_object_unref(plugin_port);
+    }
+
+    g_free(specifier);
     
     /* iterate */
     port = port->next;
@@ -158,6 +226,11 @@ ags_select_acceleration_dialog_add_callback(GtkWidget *button,
 
   next_channel = NULL;
 
+  collected_output_specifier = (gchar **) malloc(sizeof(gchar*));
+
+  collected_output_specifier[0] = NULL;
+  length = 1;
+
   while(channel != NULL){
     /* output */
     port =
@@ -170,6 +243,10 @@ ags_select_acceleration_dialog_add_callback(GtkWidget *button,
 
       gboolean is_enabled;
       gboolean contains_control_name;
+
+      plugin_port = NULL;
+    
+      specifier = NULL;
     
       g_object_get(port->data,
 		   "specifier", &specifier,
@@ -177,26 +254,35 @@ ags_select_acceleration_dialog_add_callback(GtkWidget *button,
 		   NULL);
 
 #ifdef HAVE_GLIB_2_44
-      contains_control_name = g_strv_contains(collected_specifier,
+      contains_control_name = g_strv_contains(collected_output_specifier,
 					      specifier);
 #else
-      contains_control_name = ags_strv_contains(collected_specifier,
+      contains_control_name = ags_strv_contains(collected_output_specifier,
 						specifier);
 #endif
 
       if(plugin_port != NULL &&
 	 !contains_control_name){
-	gtk_combo_box_text_append_text(combo_box,
-				       g_strdup(specifier));
+	gtk_list_store_append(list_store, &iter);
+	gtk_list_store_set(list_store, &iter,
+			   0, g_strdup("output"),
+			   1, g_strdup(specifier),
+			   -1);      
 
 	/* add to collected specifier */
-	collected_specifier = (gchar **) realloc(collected_specifier,
-						 (length + 1) * sizeof(gchar *));
-	collected_specifier[length - 1] = g_strdup(specifier);
-	collected_specifier[length] = NULL;
+	collected_output_specifier = (gchar **) realloc(collected_output_specifier,
+							(length + 1) * sizeof(gchar *));
+	collected_output_specifier[length - 1] = g_strdup(specifier);
+	collected_output_specifier[length] = NULL;
 
 	length++;
       }
+
+      if(plugin_port != NULL){
+	g_object_unref(plugin_port);
+      }
+
+      g_free(specifier);
     
       /* iterate */
       port = port->next;
@@ -232,6 +318,11 @@ ags_select_acceleration_dialog_add_callback(GtkWidget *button,
 
   next_channel = NULL;
 
+  collected_input_specifier = (gchar **) malloc(sizeof(gchar*));
+
+  collected_input_specifier[0] = NULL;
+  length = 1;
+
   while(channel != NULL){
     /* input */
     port =
@@ -244,6 +335,10 @@ ags_select_acceleration_dialog_add_callback(GtkWidget *button,
 
       gboolean is_enabled;
       gboolean contains_control_name;
+
+      plugin_port = NULL;
+    
+      specifier = NULL;
     
       g_object_get(port->data,
 		   "specifier", &specifier,
@@ -251,26 +346,35 @@ ags_select_acceleration_dialog_add_callback(GtkWidget *button,
 		   NULL);
 
 #ifdef HAVE_GLIB_2_44
-      contains_control_name = g_strv_contains(collected_specifier,
+      contains_control_name = g_strv_contains(collected_input_specifier,
 					      specifier);
 #else
-      contains_control_name = ags_strv_contains(collected_specifier,
+      contains_control_name = ags_strv_contains(collected_input_specifier,
 						specifier);
 #endif
 
       if(plugin_port != NULL &&
 	 !contains_control_name){
-	gtk_combo_box_text_append_text(combo_box,
-				       g_strdup(specifier));
+	gtk_list_store_append(list_store, &iter);
+	gtk_list_store_set(list_store, &iter,
+			   0, g_strdup("input"),
+			   1, g_strdup(specifier),
+			   -1);      
 
 	/* add to collected specifier */
-	collected_specifier = (gchar **) realloc(collected_specifier,
+	collected_input_specifier = (gchar **) realloc(collected_input_specifier,
 						 (length + 1) * sizeof(gchar *));
-	collected_specifier[length - 1] = g_strdup(specifier);
-	collected_specifier[length] = NULL;
+	collected_input_specifier[length - 1] = g_strdup(specifier);
+	collected_input_specifier[length] = NULL;
 
 	length++;
       }
+
+      if(plugin_port != NULL){
+	g_object_unref(plugin_port);
+      }
+
+      g_free(specifier);
     
       /* iterate */
       port = port->next;
@@ -296,7 +400,9 @@ ags_select_acceleration_dialog_add_callback(GtkWidget *button,
     g_object_unref(next_channel);
   }
   
-  g_strfreev(collected_specifier);
+  g_strfreev(collected_audio_specifier);
+  g_strfreev(collected_output_specifier);
+  g_strfreev(collected_input_specifier);
   
   /* remove button */
   remove = (GtkButton *) gtk_button_new_with_mnemonic(i18n("_Remove"));
